@@ -1,7 +1,7 @@
 /* ppmtofb - Display P?M graphics on framebuffer devices
  *
  *   Copyright 1996 by Geert Uytterhoeven
- *   Copyright 1996-2000 by Chris Lawrence
+ *   Copyright 1996-2001 by Chris Lawrence
  *
  *  This file is subject to the terms and conditions of the GNU General Public
  *  License.  See the file COPYING in the main directory of the Linux
@@ -45,6 +45,7 @@
 #include <endian.h>
 #include <popt.h>
 #include <time.h>
+#include <string.h>
 
 #include "version.h"
 
@@ -1442,7 +1443,7 @@ int main(int argc, char *argv[])
 
   ProgramName = argv[0];
 
-  optCon = poptGetContext("ppmtofb", argc, argv, options, 0);
+  optCon = poptGetContext("ppmtofb", argc, (const char **)argv, options, 0);
   poptReadDefaultConfig(optCon, 0);
 
   while ((c = poptGetNextOpt(optCon)) >= 0) {
@@ -1482,7 +1483,7 @@ int main(int argc, char *argv[])
         poptStrerror(c));
   }
 
-  Files = poptGetArgs(optCon);
+  Files = (char **)poptGetArgs(optCon);
 
   if ((!Files || !Files[0]) && !use_stdin) {
     Die("You must specify at least one file to view or the --stdin switch.\n"
